pub fn all_official() -> Vec<PackageItem>Expand description
What: Return the entire official index as a list of PackageItems.
Inputs:
- None
Output:
- Vector of all official items mapped to
PackageItem.
Details:
- Clones data from the shared index under a read lock and omits popularity data.